var examples =
[
    [ "Segment_Delaunay_graph_2/sdg-count-sites.cpp", "Segment_Delaunay_graph_2_2sdg-count-sites_8cpp-example.html", null ],
    [ "Segment_Delaunay_graph_2/sdg-filtered-traits.cpp", "Segment_Delaunay_graph_2_2sdg-filtered-traits_8cpp-example.html", null ],
    [ "Segment_Delaunay_graph_2/sdg-info-set.cpp", "Segment_Delaunay_graph_2_2sdg-info-set_8cpp-example.html", null ],
    [ "Segment_Delaunay_graph_2/sdg-red-blue-info.cpp", "Segment_Delaunay_graph_2_2sdg-red-blue-info_8cpp-example.html", null ],
    [ "Segment_Delaunay_graph_2/sdg-voronoi-edges.cpp", "Segment_Delaunay_graph_2_2sdg-voronoi-edges_8cpp-example.html", null ],
    [ "Segment_Delaunay_graph_2/sdg-fast-sp.cpp", "Segment_Delaunay_graph_2_2sdg-fast-sp_8cpp-example.html", null ],
    [ "Segment_Delaunay_graph_2/sdg-fast-sp-polygon.cpp", "Segment_Delaunay_graph_2_2sdg-fast-sp-polygon_8cpp-example.html", null ]
];